.. _user_guide:


User Guide
##########

Welcome! If you haven't already, see the :ref:`installation` section for instructions
on how to install **ASteCA**.

This section provides a brief overview of the main modules in **ASteCA** and
their functionalities:

.. toctree::
   :titlesonly:
   :maxdepth: 1

   cluster_mod
   membership_mod
   isochrones_mod
   synthetic_mod
   likelihood_mod


.. seealso::
   The :ref:`tutorials` section provides a step-by-step guide to using **ASteCA**,
   including examples of how to analyze a cluster's structure, estimate its membership
   probabilities, generate synthetic clusters, and estimate fundamental parameters.


.. seealso::
   The :ref:`api` section contains a complete list of the available modules and
   classes, along with their respective methods and attributes.